summaryrefslogtreecommitdiffstats
path: root/ash/wm/app_list_controller.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-10-30 04:07:02 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-10-30 04:07:02 +0000
commit33c27919dbef6edb04d8875b2ec4e3bca66f417a (patch)
treefebefa95de5ccdf6d6dd0dc0ab85adf09227772c /ash/wm/app_list_controller.cc
parenta4687623482006b61c4720e0b67a21889fb9da69 (diff)
downloadchromium_src-33c27919dbef6edb04d8875b2ec4e3bca66f417a.zip
chromium_src-33c27919dbef6edb04d8875b2ec4e3bca66f417a.tar.gz
chromium_src-33c27919dbef6edb04d8875b2ec4e3bca66f417a.tar.bz2
ash: Rename LauncherIconObserver to ShelfIconObserver.
And moves from launcher/ to shelf/ directory. BUG=248353 TEST=None, no behavior changes. R=harrym@chromium.org,jamescook@chromium.org Review URL: https://codereview.chromium.org/45973003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@231738 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/wm/app_list_controller.cc')
-rw-r--r--ash/wm/app_list_controller.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/ash/wm/app_list_controller.cc b/ash/wm/app_list_controller.cc
index 68af351..df3f724 100644
--- a/ash/wm/app_list_controller.cc
+++ b/ash/wm/app_list_controller.cc
@@ -375,9 +375,9 @@ void AppListController::OnShelfAlignmentChanged(aura::Window* root_window) {
}
////////////////////////////////////////////////////////////////////////////////
-// AppListController, LauncherIconObserver implementation:
+// AppListController, ShelfIconObserver implementation:
-void AppListController::OnLauncherIconPositionsChanged() {
+void AppListController::OnShelfIconPositionsChanged() {
UpdateBounds();
}